#![allow(dead_code)]

pub mod code; pub use code::*;
pub mod packet; pub use packet::*;

#[derive(Clone)]
pub enum QRPacketData {
    None,

    QConn(LocalPacketConnect),
    RConn,

    QDisconn,

    QHello,
    RHello(PacketHelloResponse),

    QRegister(PacketRegister),
    RRegister(PacketRegisterResponse),

    QAuth(PacketAuth),
    RAuth(PacketAuthResponse),

    QAuthResume(PacketAuthResume),
    RAuthResume(PacketAuthResumeResponse),

    QAuthRevoke,

    QUserList,
    RUserList(PacketUserListResponse),

    QSessionList(PacketSessionList),
    RSessionList(PacketSessionListResponse),

    QSessionView(PacketSessionView),
    RSessionView(PacketSessionViewResponse),

    QSessionRetire(PacketSessionRetire),

    QSessionLeave,

    QGameState(PacketGameState),
    RGameState(PacketGameStateResponse),

    GameMessage(PacketGameMessage),

    QChallenge(PacketChallenge),
    
    QChallengeAnswer(PacketChallengeAnswer),
    RChallengeAnswer(PacketChallengeAnswerResponse),

    QChallengeList,
    RChallengeList(PacketChallengeListResponse),
}

#[derive(Clone)]
pub struct QRPacket {
    pub id:u32,
    pub data:QRPacketData,
}
impl QRPacket {
    pub fn new(id:u32, data:QRPacketData) -> Self
    {
        Self { id, data }
    }
}
